Struct style::stylesheets::keyframes_rule::KeyframeSelector
[−]
[src]
pub struct KeyframeSelector(_);
A keyframes selector is a list of percentages or from/to symbols, which are converted at parse time to percentages.
Methods
impl KeyframeSelector[src]
pub fn percentages(&self) -> &[KeyframePercentage][src]
Return the list of percentages this selector contains.
pub fn new_for_unit_testing(
percentages: Vec<KeyframePercentage>
) -> KeyframeSelector[src]
percentages: Vec<KeyframePercentage>
) -> KeyframeSelector
A dummy public function so we can write a unit test for this.
pub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>>[src]
Parse a keyframe selector from CSS input.